@@ -137,7 +137,6 @@ module GI.Gio.Constants
     pattern FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE,
     pattern FILE_ATTRIBUTE_ACCESS_CAN_DELETE,
     pattern DRIVE_IDENTIFIER_KIND_UNIX_DEVICE,
-    pattern DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME,
     pattern DEBUG_CONTROLLER_EXTENSION_POINT_NAME,
     pattern DBUS_METHOD_INVOCATION_UNHANDLED,
     pattern DBUS_METHOD_INVOCATION_HANDLED  ,
@@ -1165,11 +1164,6 @@ pattern FILE_ATTRIBUTE_ACCESS_CAN_DELETE = "access::can-delete" :: T.Text
 -- /Since: 2.58/
 pattern DRIVE_IDENTIFIER_KIND_UNIX_DEVICE = "unix-device" :: T.Text
 
-{-# DEPRECATED DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME ["(Since version 2.28)","The t'GI.Gio.Interfaces.DesktopAppInfoLookup.DesktopAppInfoLookup' interface is deprecated and","   unused by GIO."] #-}
--- | Extension point for default handler to URI association. See
--- <http://developer.gnome.org/gio/stable/overview.html#extending-gio Extending GIO>.
-pattern DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME = "gio-desktop-app-info-lookup" :: T.Text
-
 -- | Extension point for debug control functionality.
 -- See <http://developer.gnome.org/gio/stable/overview.html#extending-gio Extending GIO>.
 -- 
@@ -1195,6 +1189,8 @@ pattern DBUS_METHOD_INVOCATION_UNHANDLED = P.False :: Bool
 -- In code that needs to be backwards-compatible with older GLib,
 -- use 'P.True' instead, often written like this:
 -- 
+-- 
+-- 	
 -- >
 -- >  g_dbus_method_invocation_return_error (invocation, ...);
 -- >  return TRUE;    // handled
